@@ -85,8 +85,6 @@ class Field(object):
         self.use_vocab = use_vocab
         self.init_token = init_token
         self.eos_token = eos_token
-        if fix_length:
-            assert isinstance(fix_length, int), "fix_length must be int"
         self.fix_length = fix_length
         self.final_dtype = final_dtype
         self.preprocessing = preprocessing
@@ -155,7 +153,7 @@ class Field(object):
         x = deepcopy(inp_x)
         if not self.sequential:
             return x
-        if self.fix_length:
+        if isinstance(self.fix_length, int):
             max_len = self.fix_length + (self.init_token,
                                          self.eos_token).count(None) - 2
         else:
@@ -267,8 +265,8 @@ class Field(object):
                            **kwargs)
 
     def get_max_len(self):
-        max_len = getattr(self, 'max_len') + (self.init_token,
-                                              self.eos_token).count(None) - 2
+        max_len = getattr(self, 'max_len') - (self.init_token,
+                                              self.eos_token).count(None) + 2
         return max_len
 
     def __eq__(self, other):
